import combo.public.views
from agendas.urls import urlpatterns as agendas_urlpatterns
from ckeditor.views import browse as ckeditor_browse
from ckeditor.views import upload as ckeditor_upload
from combo.manager.urls import urlpatterns as combo_manager_urls
from combo.public.views import snapshot as combo_snapshot_view
from django.conf import settings
from django.conf.urls import include, url
from django.contrib import admin
from django.contrib.auth import views as auth_views
from django.contrib.auth.decorators import login_required
from django.urls import path, reverse_lazy
from django.views.generic import RedirectView
from emissions.models import Emission, Episode, NewsItem
from emissions.urls import urlpatterns as emissions_urlpatterns
from matos.urls import urlpatterns as matos_urlpatterns
from newsletter.urls import management_patterns as newsletter_urlpatterns
from nonstop.urls import public_urlpatterns as nonstop_public_urlpatterns
from nonstop.urls import urlpatterns as nonstop_urlpatterns
from panikombo.urls import urlpatterns as panikombo_urlpatterns
from wiki.urls import urlpatterns as wiki_urlpatterns

from . import views
from .aa.urls import urlpatterns as aa_urlpatterns
from .forms import AuthenticationForm
from .oauth.urls import urlpatterns as oauth_urlpatterns
from .oauth.views import well_known_openid_configuration
from .pige.urls import urlpatterns as pige_urlpatterns
from .poll import views as poll_views
from .regie.urls import urlpatterns as regie_urlpatterns
from .service_messages.urls import urlpatterns as service_messages_urlpatterns
from .urls_utils import cms_permission_required, decorated_includes

urlpatterns = [
    url(r'^$', views.home, name='home'),
    url(r'^ckeditor/upload/', login_required(ckeditor_upload)),
    url(r'^ckeditor/browse/', login_required(ckeditor_browse)),
    url(r'^search/', login_required(views.search), name='panikdb-search'),
    url(r'^emissions/$', views.emissions_list, name='emission-list'),
    url(r'^emissions/', decorated_includes(login_required, include(emissions_urlpatterns))),
    url(r'^matos/', decorated_includes(login_required, include(matos_urlpatterns))),
    url(r'^nonstop/', decorated_includes(login_required, include(nonstop_urlpatterns))),
    url(r'^nonstop/', include(nonstop_public_urlpatterns)),
    url(r'^newsletters/add$', views.newsletter_create, name='newsletter-create'),
    url(r'^newsletters/', decorated_includes(login_required, include(newsletter_urlpatterns))),
    url(r'^cms/', decorated_includes(cms_permission_required, include(combo_manager_urls))),
    url(
        r'^cms-snapshot/(?P<pk>\w+)/$',
        cms_permission_required(combo_snapshot_view),
        name='combo-snapshot-view',
    ),
    url(r'^news/$', views.news, name='news-list'),
    url(r'^focus/set/(?P<object_type>[\w,-]+)/(?P<object_id>\d+)$', views.focus_set, name='focus-set'),
    url(r'^focus/unset/(?P<object_type>[\w,-]+)/(?P<object_id>\d+)$', views.focus_unset, name='focus-unset'),
    url(r'^accounts/logout/', auth_views.logout_then_login, name='logout'),
    url(
        r'^accounts/password/reset/$',
        auth_views.PasswordResetView.as_view(
            success_url=reverse_lazy('auth_password_reset_done'),
            email_template_name='registration/password_reset_email.html',
        ),
    ),
    url(
        r'^accounts/login/$',
        auth_views.LoginView.as_view(authentication_form=AuthenticationForm),
        name='login',
    ),
    url(
        r'^password/change/$',
        auth_views.PasswordChangeView.as_view(success_url=reverse_lazy('auth_password_change_done')),
        name='auth_password_change',
    ),
    url(
        r'^password/change/done/$',
        auth_views.PasswordChangeDoneView.as_view(),
        name='auth_password_change_done',
    ),
    url(
        r'^password/reset/$',
        auth_views.PasswordResetView.as_view(success_url=reverse_lazy('auth_password_reset_done')),
        name='auth_password_reset',
    ),
    url(
        r'^password/reset/done/',
        auth_views.PasswordResetCompleteView.as_view(),
        name='password_reset_complete',
    ),
    url(r'^accounts/', include('registration.backends.default.urls')),
    url(r'^vote/$', poll_views.vote, name='vote'),
    url(r'^vote/results/$', poll_views.vote_results, name='vote-results'),
    url(
        r'^ajax/cell/(?P<page_pk>\d+)/(?P<cell_reference>[\w_]+-\d+)/$',
        combo.public.views.ajax_page_cell,
        name='combo-public-ajax-page-cell',
    ),
    url(r'^agendas/', decorated_includes(login_required, include(agendas_urlpatterns))),
    url(r'^panikombo/', include(panikombo_urlpatterns)),
    url(r'^wiki/', include(wiki_urlpatterns)),
    url(r'^pige/', include(pige_urlpatterns)),
    url(r'^regie/', include(regie_urlpatterns)),
    url(r'^oauth/', include(oauth_urlpatterns)),
    url(r'^\.well-known/openid-configuration$', well_known_openid_configuration),
    url(r'^messages/', include(service_messages_urlpatterns)),
    url(r'^admin/', admin.site.urls),
]

urlpatterns += aa_urlpatterns

from combo import plugins

urlpatterns = plugins.register_plugins_urls(urlpatterns)

from django.contrib.staticfiles.urls import staticfiles_urlpatterns

urlpatterns += staticfiles_urlpatterns()

from django.conf.urls.static import static

urlpatterns += static(settings.MEDIA_URL, document_root=settings.MEDIA_ROOT)

if settings.DEBUG_TOOLBAR:
    urlpatterns += [
        path('__debug__/', include('debug_toolbar.urls')),
    ]
